PerksFileSyncAdapter class

PerksFileSyncAdapter is same as PerksFileAdapter but everything is synchronous.

Inheritance

Constructors

PerksFileSyncAdapter(String path)

Properties

file → File
no setter
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → String
override
toString() → String
A string representation of this object.
inherited
write(String data) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited