PerksNameValueBox<T> class

PerksNameValueBox is a Key-Value or Name-Value paired database. Everything is stored as json internally.

Inheritance

Constructors

PerksNameValueBox({required PerksAdapter adapter, bool cache = true})

Properties

adapter → PerksAdapter
finalinherited
cache → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

all() → Future<PerksNameValueMap<T>>
clear() → Future<PerksNameValueMap<T>>
delete(String key) → Future<T?>
get(String key) → Future<T?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overwrite(PerksNameValueMap<T> data) → Future<void>
set(String key, T value) → Future<void>
toString() → String
A string representation of this object.
inherited
transaction(PerksNameValueTransactionFn<T> fn) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited