PerksStringBox<T extends PerksAdapter> class

PerksStringBox provides basic functionality of storing texts.

Inheritance

Constructors

PerksStringBox({required T adapter})

Properties

adapter → T
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get() → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String value) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited